==> datasette-pretty-traces-0.1.tar.gz: datasette-pretty-traces-0.1/README.md <==
# datasette-pretty-traces

[![PyPI](https://img.shields.io/pypi/v/datasette-pretty-traces.svg)](https://pypi.org/project/datasette-pretty-traces/)
[![Changelog](https://img.shields.io/github/v/release/simonw/datasette-pretty-traces?include_prereleases&label=changelog)](https://github.com/simonw/datasette-pretty-traces/releases)
[![Tests](https://github.com/simonw/datasette-pretty-traces/workflows/Test/badge.svg)](https://github.com/simonw/datasette-pretty-traces/actions?query=workflow%3ATest)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/simonw/datasette-pretty-traces/blob/main/LICENSE)

Prettier formatting for `?_trace=1` traces

## Installation

Install this plugin in the same environment as Datasette.

    $ datasette install datasette-pretty-traces

## Usage

Once installed, run Datasette using `--setting trace_debug 1`:

    datasette fixtures.db --setting trace_debug 1

Then navigate to any page and add `?_trace=` to the URL:

    http://localhost:8001/?_trace=1

The plugin will scroll you down the page to the visualized trace information.

## Screenshot

![Screenshot showing the visualization produced by the plugin](https://user-images.githubusercontent.com/9599/145877989-dddc8be6-5b7c-4cc2-a70a-ca18aea7cd02.png)

## Development

To set up this plugin locally, first checkout the code. Then create a new virtual environment:

    cd datasette-pretty-traces
    python3 -mvenv venv
    source venv/bin/activate

Or if you are using `pipenv`:

    pipenv shell

Now install the dependencies and test dependencies:

    pip install -e '.[test]'

To run the tests:

    pytest

==> datasette-pretty-traces-0.4.tar.gz: datasette-pretty-traces-0.4/README.md <==
# datasette-pretty-traces

[![PyPI](https://img.shields.io/pypi/v/datasette-pretty-traces.svg)](https://pypi.org/project/datasette-pretty-traces/)
[![Changelog](https://img.shields.io/github/v/release/simonw/datasette-pretty-traces?include_prereleases&label=changelog)](https://github.com/simonw/datasette-pretty-traces/releases)
[![Tests](https://github.com/simonw/datasette-pretty-traces/workflows/Test/badge.svg)](https://github.com/simonw/datasette-pretty-traces/actions?query=workflow%3ATest)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/simonw/datasette-pretty-traces/blob/main/LICENSE)

Prettier formatting for `?_trace=1` traces

## Installation

Install this plugin in the same environment as Datasette.

    $ datasette install datasette-pretty-traces

## Usage

Once installed, run Datasette using `--setting trace_debug 1`:

    datasette fixtures.db --setting trace_debug 1

Then navigate to any page and add `?_trace=` to the URL:

    http://localhost:8001/?_trace=1

The plugin will scroll you down the page to the visualized trace information.

## Demo

You can try out the demo here:

- [/?_trace=1](https://latest-with-plugins.datasette.io/?_trace=1) tracing the homepage
- [/github/commits?_trace=1](https://latest-with-plugins.datasette.io/github/commits?_trace=1) tracing a table page

## Screenshot

![Screenshot showing the visualization produced by the plugin](https://user-images.githubusercontent.com/9599/145883732-a53accdd-5feb-4629-94cd-f73407c7943d.png)

## Development

To set up this plugin locally, first checkout the code. Then create a new virtual environment:

    cd datasette-pretty-traces
    python3 -mvenv venv
    source venv/bin/activate

Or if you are using `pipenv`:

    pipenv shell

Now install the dependencies and test dependencies:

    pip install -e '.[test]'

To run the tests:

    pytest
